<?php

namespace WPGPL\Child;

if (!defined('ABSPATH')) {
    exit;
}

use WPGPL\Child\Utils\DisconnectHandler;
use WPGPL\Child\Api\InstallApi;
use WPGPL\Child\Api\SiteInfoApi;
use WPGPL\Child\Api\DeleteIpApi;
use WPGPL\Child\Events\BackupHooks;
use WPGPL\Child\Utils\BackupUtils;

class WpgplChild {

    public static function init() {
        self::register_hooks();
    }

    private static function register_hooks() {
        add_action('rest_api_init', [InstallApi::class, 'register_routes']);
        add_action('rest_api_init', [SiteInfoApi::class, 'register_routes']);
        add_action('rest_api_init', [DeleteIpApi::class, 'register_routes']);
        add_action('upgrader_process_complete', [self::class, 'send_site_info']);
        add_action('deleted_theme', [self::class, 'send_site_info']);
        add_action('deleted_plugin', [self::class, 'send_site_info']);
        add_action('admin_notices', [self::class, 'connection_notice']);
        register_deactivation_hook(WPGPL_CHILD_PLUGIN_PATH . 'wpgpl-child.php', [__CLASS__, 'deactivate']);
        BackupHooks::init();
    }

    public static function connection_notice() {
        $authorized_ip = get_option('wpgpl_child_authorized_ip');

        if (empty($authorized_ip)) {
            echo '<div class="notice notice-warning is-dismissible">';
            echo '<p><img src="https://media.wpgpl.com.br/wp-content/uploads/2024/05/29132359/Logo-1.svg" alt="Aviso" style="width: 20px; vertical-align: middle; margin-right: 5px;">';
            echo '<strong>Atenção:</strong> O plugin WPGPL Child não está conectado com o WPGPL Vault. Por favor, configure a conexão para garantir o funcionamento adequado.</p>';
            echo '</div>';
        }
    }

    public static function deactivate() {
        DisconnectHandler::disconnect();
        delete_option('wpgpl_child_authorized_ip');
        delete_option('wpgpl_child_main_domain');
    }

    public static function send_site_info() {
        $main_domain = get_option('wpgpl_child_main_domain');
        $home_domain = parse_url(home_url(), PHP_URL_HOST);

        if (empty($main_domain)) {
            error_log('wpgpl_send_site_info: Domínio principal não encontrado em wpgpl_child_main_domain.');
            return;
        }
        
        wp_clean_plugins_cache();

        $site_info = array(
            'name'        => get_bloginfo('name'),
            'description' => get_bloginfo('description'),
            'url'         => home_url(),
            'wp_version'  => get_bloginfo('version'),
            'theme'       => wp_get_theme()->get('Name'),
            'theme_version' => wp_get_theme()->get('Version'),
            'backup_active' => BackupUtils::is_backup_installed(),
        );

        include_once(ABSPATH . 'wp-admin/includes/plugin.php');
        $all_plugins = get_plugins();
        $plugins = array();
        foreach ($all_plugins as $plugin_file => $plugin_data) {
            $plugins[] = array(
                'name'    => $plugin_data['Name'],
                'version' => $plugin_data['Version'],
                'active'  => is_plugin_active($plugin_file),
            );
        }

        $all_themes = wp_get_themes();
        $themes = array();
        foreach ($all_themes as $theme_slug => $theme_obj) {
            $themes[] = array(
                'name'    => $theme_obj->get('Name'),
                'version' => $theme_obj->get('Version'),
                'active'  => $theme_obj->get_stylesheet() === wp_get_theme()->get_stylesheet(),
            );
        }

        $data = array(
            'domain'    => $home_domain,
            'site_info' => $site_info,
            'plugins'   => $plugins,
            'themes'    => $themes,
        );

        error_log('wpgpl_send_site_info: Dados que serão enviados: ' . print_r($data, true));

        $response = wp_remote_post("https://{$main_domain}/wp-json/wpgpl-vault/v1/update-site?domain=" . urlencode($home_domain), array(
            'method'    => 'PUT',
            'body'      => json_encode($data),
            'headers'   => array(
                'Content-Type' => 'application/json',
            ),
            'timeout' => 30
        ));

        if (is_wp_error($response)) {
            error_log('wpgpl_send_site_info: Erro ao enviar informações do site. Detalhes do erro: ' . $response->get_error_message());
        } else {
            $status_code = wp_remote_retrieve_response_code($response);
            $response_body = wp_remote_retrieve_body($response);
            if ($status_code !== 200) {
                error_log('wpgpl_send_site_info: Erro na API ao enviar informações do site. Código de resposta: ' . $status_code . '. Resposta da API: ' . $response_body);
            } else {
                error_log('wpgpl_send_site_info: Informações enviadas com sucesso. Código de resposta: ' . $status_code);
            }
        }
    }
}

