<?php

if (!defined('ABSPATH')) {
    exit;
}

function wpgpl_vault_clear_admin_notice() {
    wpgpl_vault_delete_option('wpgpl_vault_updated_items');
}
add_action('wp_ajax_wpgpl_vault_clear_admin_notice', 'wpgpl_vault_clear_admin_notice');

function wpgpl_update_automatic_update_status() {
    // Verifica o nonce de segurança para evitar solicitações fraudulentas
    check_ajax_referer('wpgpl_vault_nonce', 'security');

    // Verifica se a solicitação foi feita por um usuário autorizado
    if (!current_user_can('manage_options')) {
        wp_send_json_error(['message' => 'Não autorizado'], 403);
    }

    // Obtém o valor do status enviado pelo AJAX e faz a depuração do valor recebido
    $status = isset($_POST['status']) ? intval($_POST['status']) : 0; // Certifique-se de usar 'status' aqui

    // Atualiza a opção no banco de dados e verifica se a atualização foi bem-sucedida
    $update_success = wpgpl_vault_update_option('wpgpl_vault_backup_integration', $status);
    
    if ($update_success) {
        // Chama a ação personalizada após atualizar a opção
        do_action('wpgpl_check_automatic_update');
        
        // Retorna a resposta de sucesso
        wp_send_json_success(['message' => 'Status atualizado para ' . $status]);
    } else {
        // Log de erro caso a atualização falhe
        error_log('Falha ao atualizar a opção no banco de dados.');

        // Retorna a resposta de erro se a atualização falhar
        wp_send_json_error(['message' => 'Falha ao atualizar o status'], 500);
    }
}
add_action('wp_ajax_wpgpl_update_automatic_update_status', 'wpgpl_update_automatic_update_status');

function wpgpl_load_history() {
    $items_per_page = 30;
    $page = isset($_POST['page']) ? intval($_POST['page']) : 1;

    // Obtenha o histórico do banco de dados
    $history_data = wpgpl_vault_get_option('wpgpl_vault_history', []);
    if (!is_array($history_data)) {
        $history_data = [];
    }

    $total_items = count($history_data);
    $total_pages = ceil($total_items / $items_per_page);

    if ($page > $total_pages) {
        wp_send_json_success(array(
            'content' => '<tr><td colspan="3" style="text-align:center;">Nenhum registro encontrado.</td></tr>',
            'total_pages' => $total_pages
        ));
        wp_die(); // Sempre necessário em chamadas AJAX no WordPress
    }

    $offset = ($page - 1) * $items_per_page;
    $paginated_data = array_slice($history_data, $offset, $items_per_page);

    if (!empty($paginated_data)) {
        ob_start();
        foreach ($paginated_data as $entry) {
            echo '<tr>';
            echo '<td><span class="wpgpl-vault-acao">' . esc_html($entry['acao']) . '</span></td>';
            
            // Verifique se o texto contém "WPGPL Vault" e substitua pelo nome do plugin
            $conteudo = esc_html($entry['conteudo']);
            if (strpos($conteudo, 'WPGPL Vault') !== false) {
                $conteudo = str_replace('WPGPL Vault', $GLOBALS['wpgpl_plugin_name'], $conteudo);
            }
            echo '<td>' . $conteudo . '</td>';
            
            echo '<td>' . esc_html($entry['data']) . '</td>';
            echo '</tr>';
        }
        $content = ob_get_clean();
        wp_send_json_success(array(
            'content' => $content,
            'total_pages' => $total_pages
        ));
    } else {
        wp_send_json_success(array(
            'content' => '<tr><td colspan="3" style="text-align:center;">Nenhum registro encontrado.</td></tr>',
            'total_pages' => $total_pages
        ));
    }

    wp_die();
}
add_action('wp_ajax_load_history', 'wpgpl_load_history');
add_action('wp_ajax_nopriv_load_history', 'wpgpl_load_history');

function wpgpl_archive_item() {
    $name = $_POST['name'];
    $path = $_POST['path']; // Recebe o path
    $type = $_POST['type'];

    $item = [
        'name' => $name, 
        'path' => $path, // Adiciona o path ao item
        'type' => $type
    ];

    wpgpl_add_to_archived_items($item);

    wp_send_json_success();
}
add_action('wp_ajax_wpgpl_archive_item', 'wpgpl_archive_item');

function wpgpl_unarchive_item() {
    $path = $_POST['path']; // Agora usamos o path

    wpgpl_remove_from_archived_items($path);

    wp_send_json_success();
}
add_action('wp_ajax_wpgpl_unarchive_item', 'wpgpl_unarchive_item');

function wpgpl_vault_store_outdated_item() {
    check_ajax_referer('wpgpl_vault_nonce', 'security');

    $name = sanitize_text_field($_POST['name']);
    $version = sanitize_text_field($_POST['version']);
    $current_version = sanitize_text_field($_POST['current_version']);
    $path = sanitize_text_field($_POST['path']); // Recebe o path enviado pelo JS

    // Obtém os itens desatualizados já armazenados
    $outdated_items = wpgpl_vault_get_option('wpgpl_vault_items_outdate', []);

    // Variável para verificar se o item foi atualizado
    $item_updated = false;

    // Verifica se o item já está no array para evitar duplicatas ou atualizar se necessário
    foreach ($outdated_items as &$item) {
        if ($item['path'] === $path) { // Compara pelo path
            // Se a versão atual for menor que a nova versão fornecida, atualiza o item
            if (version_compare($item['version'], $version, '<')) {
                $item['version'] = $version;
                $item['current_version'] = $current_version;
                $item['status'] = 'Desatualizado';
                $item['needs_update'] = true;
                $item_updated = true;
                break;
            } else {
                wp_send_json_success('Item já armazenado e atualizado');
                return;
            }
        }
    }

    // Se o item não foi atualizado, adiciona como um novo item desatualizado ao array
    if (!$item_updated) {
        $outdated_items[] = [
            'name' => $name,
            'version' => $version,
            'current_version' => $current_version,
            'path' => $path, // Armazena o path
            'status' => 'Desatualizado',
            'needs_update' => true
        ];
    }

    // Atualiza a opção no banco de dados
    wpgpl_vault_update_option('wpgpl_vault_items_outdate', $outdated_items);

    // Adiciona uma entrada ao histórico usando a função de histórico
    $action = $item_updated ? 'Item Desatualizado Atualizado' : 'Item Desatualizado Armazenado';
    $content = 'O item "' . $name . '" com a versão atual ' . $current_version . ' foi identificado como desatualizado. Nova versão: ' . $version . '.';
    wpgpl_vault_add_to_history($action, $content);

    wp_send_json_success($item_updated ? 'Item desatualizado atualizado com sucesso' : 'Item desatualizado armazenado com sucesso');
}
add_action('wp_ajax_wpgpl_vault_store_outdated_item', 'wpgpl_vault_store_outdated_item');

function wpgpl_vault_remove_outdated_item() {
    check_ajax_referer('wpgpl_vault_nonce', 'security');

    $path = sanitize_text_field($_POST['path']); // Recebe o path enviado pelo JS

    // Obtém os itens desatualizados já armazenados
    $outdated_items = wpgpl_vault_get_option('wpgpl_vault_items_outdate', []);

    // Garante que $outdated_items seja um array
    if (!is_array($outdated_items)) {
        $outdated_items = [];
    }

    // Filtra e remove o item com o path correspondente
    foreach ($outdated_items as $key => $item) {
        if ($item['path'] === $path) {
            // Adiciona uma entrada ao histórico
            wpgpl_vault_add_to_history('Item Removido', 'O item "' . $item['name'] . '" foi removido da lista de desatualizados.');

            // Remove o item do array
            unset($outdated_items[$key]);
            break; // Interrompe o loop após encontrar e remover o item
        }
    }

    // Atualiza a opção no banco de dados
    wpgpl_vault_update_option('wpgpl_vault_items_outdate', $outdated_items);

    wp_send_json_success('Item atualizado removido com sucesso');
}
add_action('wp_ajax_wpgpl_vault_remove_outdated_item', 'wpgpl_vault_remove_outdated_item');

function wpgpl_save_theme_color() {
    if (isset($_POST['theme_color'])) {
        $theme_color = intval($_POST['theme_color']);
        wpgpl_vault_update_option('wpgpl_theme_color', $theme_color);
        
        // Atualiza as variáveis globais
        wpgpl_set_global_theme_variables();

        // Retorna a nova URL do logo
        echo json_encode(array(
            'status' => 'success',
            'logo_url' => $GLOBALS['wpgpl_plugin_slogan_url']
        ));
    } else {
        echo json_encode(array(
            'status' => 'error'
        ));
    }
    wp_die(); // Sempre terminar funções AJAX com wp_die()
}
add_action('wp_ajax_wpgpl_save_theme_color', 'wpgpl_save_theme_color');

function wpgpl_deactivate_license() {
    if (!current_user_can('manage_options')) {
        wp_send_json_error(array('message' => 'Você não tem permissão para realizar esta ação.'));
        return;
    }

    // Remove as opções de licença e UUID
    wpgpl_vault_delete_option('wpgpl_vault_license_key');
    wpgpl_vault_delete_option('wpgpl_vault_uuid');

    // Adiciona uma entrada ao histórico usando a função de histórico
    $action = 'Licença Desativada';
    $content = 'A chave de licença foi desativada e removida do sistema.';
    wpgpl_vault_add_to_history($action, $content);

    wp_send_json_success(array('message' => 'Chave de licença removida com sucesso.'));
}
add_action('wp_ajax_wpgpl_deactivate_license', 'wpgpl_deactivate_license');

function save_wpgpl_vault_auto_update_plugin() {
    check_ajax_referer('wpgpl_vault_nonce', 'security');

    if (!isset($_POST['plugin']) || !isset($_POST['enabled'])) {
        wp_send_json_error('Missing required parameters.');
        return;
    }

    $plugin = sanitize_text_field($_POST['plugin']);
    $enabled = absint($_POST['enabled']);

    if (!$plugin) {
        wp_send_json_error('Plugin name is missing.');
        return;
    }

    $auto_update_plugins = wpgpl_vault_get_option('wpgpl_vault_auto_update_plugins', []);
    
    // Ensure $auto_update_plugins is an array
    if (!is_array($auto_update_plugins)) {
        $auto_update_plugins = [];
    }

    if ($enabled) {
        if (!in_array($plugin, $auto_update_plugins)) {
            $auto_update_plugins[] = $plugin;
        }
    } else {
        if (($key = array_search($plugin, $auto_update_plugins)) !== false) {
            unset($auto_update_plugins[$key]);
            $auto_update_plugins = array_values($auto_update_plugins); // Re-index array
        }
    }

    $update_result = wpgpl_vault_update_option('wpgpl_vault_auto_update_plugins', $auto_update_plugins);
    if (!$update_result) {
        wp_send_json_error('Failed to update option.');
        return;
    }

    wp_send_json_success();
}
add_action('wp_ajax_save_wpgpl_vault_auto_update_plugin', 'save_wpgpl_vault_auto_update_plugin');

function save_wpgpl_vault_auto_update_theme() {
    check_ajax_referer('wpgpl_vault_nonce', 'security');

    if (!isset($_POST['theme']) || !isset($_POST['enabled'])) {
        wp_send_json_error('Missing required parameters.');
        return;
    }

    $theme = sanitize_text_field($_POST['theme']);
    $enabled = absint($_POST['enabled']);

    if (!$theme) {
        wp_send_json_error('Theme name is missing.');
        return;
    }

    $auto_update_themes = wpgpl_vault_get_option('wpgpl_vault_auto_update_themes', []);
    
    if (!is_array($auto_update_themes)) {
        $auto_update_themes = [];
    }

    if ($enabled) {
        if (!in_array($theme, $auto_update_themes)) {
            $auto_update_themes[] = $theme;
        }
    } else {
        if (($key = array_search($theme, $auto_update_themes)) !== false) {
            unset($auto_update_themes[$key]);
            $auto_update_themes = array_values($auto_update_themes); // Re-index array
        }
    }

    $update_result = wpgpl_vault_update_option('wpgpl_vault_auto_update_themes', $auto_update_themes);
    if (!$update_result) {
        wp_send_json_error('Failed to update option.');
        return;
    }

    wp_send_json_success();
}
add_action('wp_ajax_save_wpgpl_vault_auto_update_theme', 'save_wpgpl_vault_auto_update_theme');

function wpgpl_vault_send_support_message() {
    $post_title = isset($_POST['post_title']) ? sanitize_text_field($_POST['post_title']) : '';
    $post_version = isset($_POST['post_version']) ? sanitize_text_field($_POST['post_version']) : '';
    $error_message = isset($_POST['error_message']) ? sanitize_text_field($_POST['error_message']) : '';

    if (!$post_title || !$post_version || !$error_message) {
        wp_send_json_error('Dados insuficientes para enviar a mensagem.');
    }

    $display_name = wpgpl_vault_get_option('wpgpl_display_name');
    $user_email = wpgpl_vault_get_option('wpgpl_user_email');

    $data = array(
        'post_title' => $post_title,
        'post_version' => $post_version,
        'error_message' => $error_message,
        'display_name' => $display_name,
        'user_email' => $user_email
    );

    $response = wp_remote_post(wpgpl_vault_get_endpoint_url(ENDPOINT_SUPPORT), array(
        'method' => 'POST',
        'body' => json_encode($data),
        'headers' => array(
            'Content-Type' => 'application/json'
        ),
        'timeout' => 30
    ));

    if (is_wp_error($response)) {
        wp_send_json_error('Erro ao enviar a mensagem: ' . $response->get_error_message());
    }

    $response_code = wp_remote_retrieve_response_code($response);
    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    if ($response_code == 200 && isset($data['status']) && $data['status'] === 'success') {
        // Adiciona uma entrada ao histórico usando a função de histórico
        $action = 'Mensagem de Suporte Enviada';
        $content = 'Mensagem enviada para suporte com o título "' . $post_title . '", versão: ' . $post_version . '. Mensagem de erro: "' . $error_message . '".';
        wpgpl_vault_add_to_history($action, $content);

        wp_send_json_success('Mensagem enviada com sucesso.');
    } else {
        wp_send_json_error('Erro ao enviar a mensagem. Código de resposta: ' . $response_code . ' Corpo: ' . $body);
    }
}
add_action('wp_ajax_wpgpl_vault_send_support_message', 'wpgpl_vault_send_support_message');

function save_wpgpl_vault_plugin_cron() {
    // Verifica nonce para segurança
    check_ajax_referer('wpgpl_vault_nonce', 'security');

    // Pega a configuração enviada pelo JavaScript
    $plugin_cron_enabled = isset($_POST['plugin_cron_enabled']) ? intval($_POST['plugin_cron_enabled']) : 0;

    // Atualiza a opção no banco de dados
    wpgpl_vault_update_option('wpgpl_vault_plugin_cron_enabled', $plugin_cron_enabled);
    
    do_action('wpgpl_check_automatic_update');

    // Envia resposta de sucesso ao JavaScript
    wp_send_json_success();
}
add_action('wp_ajax_save_wpgpl_vault_plugin_cron', 'save_wpgpl_vault_plugin_cron');

function save_wpgpl_vault_theme_cron() {
    // Verifica nonce para segurança
    check_ajax_referer('wpgpl_vault_nonce', 'security');

    // Pega a configuração enviada pelo JavaScript
    $theme_cron_enabled = isset($_POST['theme_cron_enabled']) ? intval($_POST['theme_cron_enabled']) : 0;

    // Atualiza a opção no banco de dados
    wpgpl_vault_update_option('wpgpl_vault_theme_cron_enabled', $theme_cron_enabled);
    
    do_action('wpgpl_check_automatic_update');

    // Envia resposta de sucesso ao JavaScript
    wp_send_json_success();
}
add_action('wp_ajax_save_wpgpl_vault_theme_cron', 'save_wpgpl_vault_theme_cron');

function wpgpl_vault_get_user_ip() {
    // Chama a API para obter o IP do usuário
    $response = wp_remote_get(
        wpgpl_vault_get_endpoint_url(ENDPOINT_IP), 
        array(
            'timeout' => 30
        )
    );

    if (is_wp_error($response)) {
        echo json_encode(array('error' => 'Erro ao obter o IP. Tente novamente!'));
    } else {
        $body = wp_remote_retrieve_body($response);

        // Adiciona uma entrada ao histórico usando a função de histórico
        $action = 'Obtenção de IP';
        $content = 'O IP do usuário foi obtido: ' . $body;
        wpgpl_vault_add_to_history($action, $content);

        echo $body;
    }
    wp_die(); // Termina a execução para retornar uma resposta adequada
}
add_action('wp_ajax_wpgpl_vault_get_user_ip', 'wpgpl_vault_get_user_ip');

function wpgpl_vault_validate_license() {
    $license_key = isset($_GET['license_key']) ? sanitize_text_field($_GET['license_key']) : '';

    if (!$license_key) {
        wp_send_json_error('Chave de licença não fornecida.');
    }

    // Fazer a requisição para verificar a licença
    $response = wp_remote_get(
        wpgpl_vault_get_endpoint_url(ENDPOINT_LICENSE) . '?license_key=' . urlencode($license_key), 
        array(
            'timeout' => 10 // Define o timeout para 10 segundos
        )
    );

    if (is_wp_error($response)) {
        wp_send_json_error('Erro na requisição para verificar a chave de licença.');
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    if (isset($data['is_valid']) && $data['is_valid']) {
        wpgpl_vault_update_option('wpgpl_user_id', $data['user_id']);
        wpgpl_vault_update_option('wpgpl_user_email', $data['user_email']);
        wpgpl_vault_update_option('wpgpl_display_name', $data['display_name']);
        wpgpl_vault_update_option('wpgpl_vault_uuid', $data['uuid']);
        wpgpl_vault_update_option('wpgpl_vault_license_key', $data['sha256']);
        
        // Verificar e salvar informações adicionais, se presentes
        if (isset($data['agency_name'])) {
            wpgpl_vault_update_option('wpgpl_agency_name', $data['agency_name']);
        }
        if (isset($data['agency_url'])) {
            wpgpl_vault_update_option('wpgpl_agency_url', $data['agency_url']);
        }
        if (isset($data['plugin_name'])) {
            wpgpl_vault_update_option('wpgpl_plugin_name', $data['plugin_name']);
        }
        if (isset($data['plugin_description'])) {
            wpgpl_vault_update_option('wpgpl_plugin_description', $data['plugin_description']);
        }
        if (isset($data['plugin_light_slogan_url'])) {
            wpgpl_vault_update_option('wpgpl_plugin_slogan_light_url', $data['plugin_light_slogan_url']);
        }
        if (isset($data['plugin_slogan_dark_url'])) {
            wpgpl_vault_update_option('wpgpl_plugin_slogan_dark_url', $data['plugin_slogan_dark_url']);
        }
        if (isset($data['plugin_icon_url'])) {
            wpgpl_vault_update_option('wpgpl_plugin_icon_url', $data['plugin_icon_url']);
            $icon_url = $data['plugin_icon_url'];
            $save_path = WPGPL_PLUGIN_PATH . 'media/icon_whitelabel.svg';
            wpgpl_download_plugin_icon($icon_url, $save_path);
        } else {
            $icon_path = WPGPL_PLUGIN_PATH . 'media/icon_whitelabel.svg';
            if (file_exists($icon_path)) {
                unlink($icon_path);
            }
        }

        // Adiciona uma entrada ao histórico para sucesso na validação
        $action = 'Licença Validada';
        $content = 'A chave de licença foi validada com sucesso para o usuário: ' . $data['uuid'];
        wpgpl_vault_add_to_history($action, $content);

        wp_send_json_success('Chave de licença válida.');
    } else {
        // Adiciona uma entrada ao histórico para falha na validação
        $action = 'Falha na Validação de Licença';
        $error_message = isset($data['message']) ? $data['message'] : 'Chave de licença inválida';
        $content = 'Tentativa de validação de licença falhou. Mensagem de erro: ' . $error_message;
        wpgpl_vault_add_to_history($action, $content);

        if (isset($data['message']) && strpos($data['message'], 'IP não autorizado') !== false) {
            wp_send_json_error(array(
                'message' => $data['message']
            ));
        } else {
            wp_send_json_error('Chave de licença inválida.');
        }
    }
}
add_action('wp_ajax_wpgpl_vault_validate_license', 'wpgpl_vault_validate_license');

function wpgpl_vault_save_license_key_callback() {
    if (!current_user_can('manage_options')) {
        wp_send_json_error('Permissão negada.');
    }

    // Chama a função para verificar a versão do plugin
    check_wpgpl_version();

    // Retorna o slug do plugin para ser utilizado na redireção
    wp_send_json_success(array('slug' => $GLOBALS['wpgpl_plugin_slug']));
}
add_action('wp_ajax_wpgpl_vault_save_license_key', 'wpgpl_vault_save_license_key_callback');

function wpgpl_vault_clear_license_notice() {
    // Esta função é chamada via AJAX quando a licença é ativada, e não precisa fazer nada aqui
    wp_send_json_success();
}
add_action('wp_ajax_wpgpl_vault_clear_license_notice', 'wpgpl_vault_clear_license_notice');

function wpgpl_vault_check_api_callback() {
    $name = isset($_GET['name']) ? sanitize_text_field($_GET['name']) : '';
    $license_key = $GLOBALS['wpgpl_license_key'];

    if (empty($name)) {
        wp_send_json_error('Nome não fornecido');
    }

    if (empty($license_key)) {
        wp_send_json_error('Chave de licença não fornecida');
    }

    $response = wp_remote_get(wpgpl_vault_get_endpoint_url(ENDPOINT_DETAILS) . '?query=' . urlencode($name), array(
        'headers' => array(
            'Authorization' => $license_key
        ),
        'timeout' => 30
    ));

    if (is_wp_error($response)) {
        wp_send_json_error('Erro na requisição');
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    if (!empty($data)) {
        wp_send_json_success($data);
    } else {
        wp_send_json_error('Nenhum dado retornado');
    }
}
add_action('wp_ajax_wpgpl_vault_check_api', 'wpgpl_vault_check_api_callback');

function wpgpl_vault_download_and_install_callback() {
    $name = isset($_POST['name']) ? sanitize_text_field($_POST['name']) : '';
    $version = isset($_POST['version']) ? sanitize_text_field($_POST['version']) : ''; // Captura a versão se enviada
    $license_key = $GLOBALS['wpgpl_license_key'];
    $type = isset($_POST['type']) ? sanitize_text_field($_POST['type']) : 'plugin'; // Adiciona o tipo de instalação: plugin ou tema

    if (empty($name)) {
        wp_send_json_error('Nome não fornecido');
    }

    if (empty($license_key)) {
        wp_send_json_error('Chave de licença não fornecida');
    }

    if (!in_array($type, ['plugin', 'theme'])) {
        wp_send_json_error('Tipo inválido fornecido');
    }

    // Faz a requisição para buscar os dados do plugin/tema
    $endpoint_url = wpgpl_vault_get_endpoint_url(ENDPOINT_SEARCH) . '?query=' . urlencode($name);
    $response = wp_remote_get($endpoint_url, array(
        'headers' => array(
            'Authorization' => $license_key
        ),
        'timeout' => 30
    ));

    if (is_wp_error($response)) {
        $error_message = $response->get_error_message();
        wpgpl_vault_add_to_history('Erro na Requisição de Instalação', 'Erro ao fazer requisição para instalar ' . $type . ' "' . $name . '": ' . $error_message);
        wp_send_json_error('Erro na requisição');
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    if (!empty($data)) {
        $download_url = '';

        // Procura pela versão específica, se informada
        if (!empty($version)) {
            foreach ($data[0]['old_versions'] as $old_version) {
                if ($old_version['old_version'] === $version) {
                    $download_url = $old_version['old_download'];
                    break;
                }
            }

            // Se não encontrou a versão antiga, retorna erro
            if (empty($download_url)) {
                wp_send_json_error('Versão antiga não encontrada');
            }
        } else {
            // Se a versão não foi informada, usa a versão atual
            $download_url = $data[0]['download'];
        }

        // Usa as funções nativas do WordPress para instalar plugin/tema
        require_once(ABSPATH . 'wp-admin/includes/class-wp-upgrader.php');

        // Configura o Upgrader
        $upgrader = ($type === 'plugin') ? new Plugin_Upgrader() : new Theme_Upgrader();

        // Força a atualização, mesmo que já exista
        $result = $upgrader->run(array(
            'package' => $download_url, // URL do download
            'destination' => ($type === 'plugin') ? WP_PLUGIN_DIR : get_theme_root(), // Diretório de destino
            'clear_destination' => true, // Limpa o diretório de destino (sobrescreve)
            'clear_working' => true, // Limpa arquivos temporários após instalação
            'hook_extra' => array(
                'type' => $type,
                'action' => 'install'
            )
        ));

        if (is_wp_error($result)) {
            $error_message = $result->get_error_message();
            wpgpl_vault_add_to_history('Erro na Instalação', 'Erro ao instalar o ' . $type . ' "' . $name . '": ' . $error_message);
            wp_send_json_error('Erro ao instalar o arquivo: ' . $error_message);
        }

        // Adiciona uma entrada ao histórico para sucesso na instalação
        $action = ucfirst($type) . ' Instalado';
        $content = 'O ' . $type . ' "' . $name . '" foi instalado com sucesso';
        if (!empty($version)) {
            $content .= ' na versão ' . $version;
        }
        wpgpl_vault_add_to_history($action, $content);

        wp_send_json_success('Arquivo instalado com sucesso');
    } else {
        $error_message = 'Nenhum dado de download retornado';
        wpgpl_vault_add_to_history('Erro na Obtenção de Dados de Download', 'Erro ao tentar obter dados de download para ' . $type . ' "' . $name . '": ' . $error_message);
        wp_send_json_error($error_message);
    }
}
add_action('wp_ajax_wpgpl_vault_download_and_install', 'wpgpl_vault_download_and_install_callback');