<?php

if (!defined('ABSPATH')) {
    exit;
}

function wpgpl_vault_check_updates() {
    
    // Verifica se a ação wpgpl_vault_automatic_updates está sendo executada no momento
    $running_automatic_updates = as_next_scheduled_action('wpgpl_vault_automatic_updates', [], 'wpgpl_vault');
    
    if ($running_automatic_updates && $running_automatic_updates <= time()) {
        error_log('wpgpl_vault_automatic_updates está rodando. Pulando execução de wpgpl_vault_check_updates.');
        return;
    }
    
    error_log('Executando verificação de atualizações...');
    
    $license_key = $GLOBALS['wpgpl_license_key'];
    if (empty($license_key)) {
        error_log('Chave de licença não fornecida');
        return;
    }

    $all_plugins = get_plugins();
    $plugin_names = [];

    if (!empty($all_plugins)) {
        foreach ($all_plugins as $plugin_data) {
            $plugin_names[] = $plugin_data['Name'];
        }
    }

    $all_themes = wp_get_themes();
    $theme_names = [];

    if (!empty($all_themes)) {
        foreach ($all_themes as $theme) {
            $theme_names[] = $theme->get('Name');
        }
    }

    $body = [
        'products' => array_merge($plugin_names, $theme_names)
    ];

    $response = wp_remote_post(wpgpl_vault_get_endpoint_url(ENDPOINT_ITEMS_CHECK), [
        'method' => 'POST',
        'body' => wp_json_encode($body),
        'headers' => [
            'Content-Type' => 'application/json',
            'Authorization' => $license_key
        ],
        'timeout' => 30
    ]);

    // Verifica se a requisição foi bem-sucedida
    if (is_wp_error($response)) {
        error_log('Erro ao fazer a requisição para o endpoint: ' . $response->get_error_message());
        return;
    }

    $response_body = wp_remote_retrieve_body($response);
    $products_status = json_decode($response_body, true);

    if (!$products_status || !is_array($products_status)) {
        error_log('Resposta inválida do endpoint.');
        return;
    }

    // Separar plugins e temas que existem
    $valid_plugins = [];
    $valid_themes = [];

    foreach ($products_status as $product) {
        if ($product['exists'] === true) {
            if (in_array($product['name'], $plugin_names)) {
                $valid_plugins[] = $product['name'];
            } elseif (in_array($product['name'], $theme_names)) {
                $valid_themes[] = $product['name'];
            }
        }
    }

    // Verificar os plugins válidos
    if (!empty($valid_plugins)) {
        foreach ($all_plugins as $plugin => $plugin_data) {
            $name = $plugin_data['Name'];
            if (in_array($name, $valid_plugins)) {
                $path = $plugin;
                try {
                    wpgpl_check_and_store_outdated_item($name, $plugin_data['Version'], $license_key, 'plugin', $path);
                    error_log("Verificação do plugin {$name} concluída com sucesso.");
                    
                    $action = 'Verificação de Plugin';
                    $content = "Verificação do plugin \"{$name}\" concluída com sucesso.";
                    wpgpl_vault_add_to_history($action, $content);
                } catch (Exception $e) {
                    error_log("Erro ao verificar o plugin {$name}: " . $e->getMessage());
                    
                    $action = 'Erro na Verificação de Plugin';
                    $content = "Erro ao verificar o plugin \"{$name}\": " . $e->getMessage();
                    wpgpl_vault_add_to_history($action, $content);
                }

                error_log('Aguardando 10 segundos antes de verificar o próximo plugin');
                sleep(10);
            }
        }
    } else {
        error_log('Nenhum plugin válido encontrado para verificação.');
    }

    // Verificar os temas válidos
    if (!empty($valid_themes)) {
        foreach ($all_themes as $theme_name => $theme) {
            $name = $theme->get('Name');
            if (in_array($name, $valid_themes)) {
                $path = $name;
                try {
                    wpgpl_check_and_store_outdated_item($name, $theme->get('Version'), $license_key, 'theme', $path);
                    error_log("Verificação do tema {$name} concluída com sucesso.");
                    
                    $action = 'Verificação de Tema';
                    $content = "Verificação do tema \"{$name}\" concluída com sucesso.";
                    wpgpl_vault_add_to_history($action, $content);
                } catch (Exception $e) {
                    error_log("Erro ao verificar o tema {$name}: " . $e->getMessage());
                    
                    $action = 'Erro na Verificação de Tema';
                    $content = "Erro ao verificar o tema \"{$name}\": " . $e->getMessage();
                    wpgpl_vault_add_to_history($action, $content);
                }

                error_log('Aguardando 10 segundos antes de verificar o próximo tema');
                sleep(10);
            }
        }
    } else {
        error_log('Nenhum tema válido encontrado para verificação.');
    }
}
add_action('wpgpl_vault_check_updates', 'wpgpl_vault_check_updates');

function wpgpl_check_and_store_outdated_item($name, $current_version, $license_key, $type, $path) {

    $response = wp_remote_get(wpgpl_vault_get_endpoint_url(ENDPOINT_DETAILS) . '?query=' . urlencode($name), array(
        'headers' => array(
            'Authorization' => $license_key
        ),
        'timeout' => 30
    ));

    if (is_wp_error($response)) {
        error_log('Erro na requisição para ' . $name);
        // Adiciona uma entrada ao histórico para erro na requisição
        $action = 'Erro na Requisição de Atualização';
        $content = 'Erro ao fazer requisição para verificar atualizações para ' . $type . ' "' . $name . '".';
        wpgpl_vault_add_to_history($action, $content);
        return;
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    if (!empty($data)) {
        $apiVersion = $data[0]['version'];
        if (version_compare($current_version, $apiVersion, '<')) {
            // Item está desatualizado, armazená-lo
            $outdated_items = wpgpl_vault_get_option('wpgpl_vault_items_outdate', []);

            // Verifica se o item já está no array para evitar duplicatas
            $item_found = false;
            foreach ($outdated_items as &$item) {
                if ($item['name'] === $name && $item['type'] === $type) {
                    // Se a versão atual for menor que a versão da API, atualiza o item
                    if (version_compare($item['version'], $apiVersion, '<')) {
                        $item['version'] = $apiVersion;
                        $item['current_version'] = $current_version;
                        $item['status'] = 'Desatualizado';
                        $item['needs_update'] = true;
                        $item['path'] = $path; // Atualiza o caminho
                    }
                    $item_found = true;
                    break;
                }
            }

            // Se o item não foi encontrado, adiciona como um novo item desatualizado ao array
            if (!$item_found) {
                $outdated_items[] = [
                    'name' => $name,
                    'version' => $apiVersion,
                    'current_version' => $current_version,
                    'status' => 'Desatualizado',
                    'needs_update' => true,
                    'type' => $type,
                    'path' => $path // Armazena o caminho
                ];
            }

            // Atualiza a opção com o array atualizado de itens desatualizados
            wpgpl_vault_update_option('wpgpl_vault_items_outdate', $outdated_items);

            error_log('Item desatualizado ' . ($item_found ? 'atualizado' : 'armazenado') . ': ' . $name);

            // Adiciona uma entrada ao histórico para item desatualizado armazenado ou atualizado
            $action = $item_found ? 'Item Desatualizado Atualizado' : 'Item Desatualizado Armazenado';
            $content = 'O ' . $type . ' "' . $name . '" está desatualizado. Versão atual: ' . $current_version . '. Nova versão: ' . $apiVersion . '. Caminho: ' . $path . '.';
            wpgpl_vault_add_to_history($action, $content);
        }
    } else {
        error_log('Nenhum dado retornado para ' . $name);
        // Adiciona uma entrada ao histórico para ausência de dados
        $action = 'Ausência de Dados de Atualização';
        $content = 'Nenhum dado de atualização retornado para ' . $type . ' "' . $name . '".';
        wpgpl_vault_add_to_history($action, $content);
    }
}