<?php

if (!defined('ABSPATH')) {
    exit;
}

if (!function_exists('get_plugins')) {
    require_once ABSPATH . 'wp-admin/includes/plugin.php';
}
if (!function_exists('wpgpl_vault_get_endpoint_url')) {
    require_once ABSPATH . 'settings.php';
}

function wpgpl_vault_automatic_updates() {
    // Log de início
    error_log('WPGPL Vault Cron Job iniciado.');

    $updated_items = array();

    // Verificar se a licença está ativa
    $license_key = $GLOBALS['wpgpl_license_key'];
    if (empty($license_key)) {
        error_log('WPGPL Vault Cron Job: Nenhuma chave de licença encontrada.');
        return;
    }

    global $GLOBALS;
    $plugin_main_name = $GLOBALS['wpgpl_plugin_name'];

    // Verificar todos os plugins e temas antes de prosseguir
    $all_plugins = get_plugins();
    $all_themes = wp_get_themes();

    $plugin_names = [];
    $theme_names = [];

    // Prepara arrays para enviar à API
    foreach ($all_plugins as $plugin_data) {
        $plugin_names[] = $plugin_data['Name'];
    }

    foreach ($all_themes as $theme) {
        $theme_names[] = $theme->get('Name');
    }

    $body = [
        'products' => array_merge($plugin_names, $theme_names)
    ];

    // Fazer POST para o endpoint com plugins e temas
    $response = wp_remote_post(wpgpl_vault_get_endpoint_url(ENDPOINT_ITEMS_CHECK), [
        'method' => 'POST',
        'body' => wp_json_encode($body),
        'headers' => [
            'Content-Type' => 'application/json',
            'Authorization' => $license_key
        ],
        'timeout' => 30
    ]);

    // Verifica se a requisição foi bem-sucedida
    if (is_wp_error($response)) {
        error_log('Erro ao fazer a requisição para o endpoint: ' . $response->get_error_message());
        return;
    }

    $response_body = wp_remote_retrieve_body($response);
    $products_status = json_decode($response_body, true);

    if (!$products_status || !is_array($products_status)) {
        error_log('Resposta inválida do endpoint.');
        return;
    }

    // Separar plugins e temas que existem
    $valid_plugins = [];
    $valid_themes = [];

    foreach ($products_status as $product) {
        if ($product['exists'] === true) {
            if (in_array($product['name'], $plugin_names)) {
                $valid_plugins[] = $product['name'];
            } elseif (in_array($product['name'], $theme_names)) {
                $valid_themes[] = $product['name'];
            }
        }
    }

    // Verificar se a atualização automática de plugins está ativada
    $plugin_cron_enabled = wpgpl_vault_get_option('wpgpl_vault_plugin_cron_enabled', false);
    $auto_update_plugins = wpgpl_vault_get_option('wpgpl_vault_auto_update_plugins', []);

    if ($plugin_cron_enabled && is_array($auto_update_plugins)) {
        foreach ($all_plugins as $plugin => $plugin_data) {
            $plugin_name = $plugin_data['Name'];
            if (in_array($plugin_name, $valid_plugins) && in_array($plugin, $auto_update_plugins)) {
                $plugin_version = $plugin_data['Version'];
                $plugin_path = $plugin;

                // Verificar a versão na API
                $response = wp_remote_get(wpgpl_vault_get_endpoint_url(ENDPOINT_SEARCH) . '?query=' . urlencode($plugin_name), array(
                    'headers' => array(
                        'Authorization' => $license_key
                    ),
                    'timeout' => 30
                ));

                if (is_wp_error($response)) {
                    error_log('WPGPL Vault Cron Job: Erro na requisição para ' . $plugin_name);
                    wpgpl_vault_add_to_history('Erro na Atualização', 'Erro ao fazer requisição para atualização do plugin ' . $plugin_name . '.');
                    continue;
                }

                $body = wp_remote_retrieve_body($response);
                $data = json_decode($body, true);

                if (!empty($data) && isset($data[0]['version'])) {
                    if (version_compare($plugin_version, $data[0]['version'], '<')) {
                        $download_url = $data[0]['download'];

                        // Usar Plugin_Upgrader para atualizar o plugin
                        require_once(ABSPATH . 'wp-admin/includes/class-wp-upgrader.php');
                        $upgrader = new Plugin_Upgrader();
                        $result = $upgrader->run(array(
                            'package' => $download_url,
                            'destination' => WP_PLUGIN_DIR,
                            'clear_destination' => true, // Sobrescreve o plugin existente
                            'clear_working' => true,
                            'hook_extra' => array('type' => 'plugin', 'action' => 'update')
                        ));

                        if (is_wp_error($result)) {
                            $error_message = $result->get_error_message();
                            error_log('WPGPL Vault Cron Job: Erro ao atualizar o plugin ' . $plugin_name . ': ' . $error_message);
                            wpgpl_vault_add_to_history('Erro na Instalação', 'Erro ao atualizar o plugin ' . $plugin_name . ': ' . $error_message);
                            continue;
                        }

                        error_log('WPGPL Vault Cron Job: Plugin ' . $plugin_name . ' atualizado com sucesso.');
                        $updated_items[] = array(
                            'type' => 'plugin',
                            'name' => $plugin_name,
                            'old_version' => $plugin_version,
                            'new_version' => $data[0]['version']
                        );
                        
                        // Remover o plugin dos itens desatualizados
                        wpgpl_remove_outdated_item($plugin_path, true);
                        
                        wpgpl_vault_add_to_history('Plugin Atualizado', 'Plugin ' . $plugin_name . ' atualizado de versão ' . $plugin_version . ' para ' . $data[0]['version'] . '.');
                    } else {
                        error_log('WPGPL Vault Cron Job: Plugin ' . $plugin_name . ' já está atualizado.');
                        wpgpl_vault_add_to_history('Plugin Já Atualizado', 'Plugin ' . $plugin_name . ' já está na versão mais recente (' . $plugin_version . ').');
                    }
                } else {
                    error_log('WPGPL Vault Cron Job: Plugin ' . $plugin_name . ' não foi encontrado na API.');
                    wpgpl_vault_add_to_history('Plugin Não Encontrado', 'Plugin ' . $plugin_name . ' não foi encontrado na API.');
                }

                error_log("Aguardando 10 segundos antes de verificar o próximo plugin");
                sleep(10);
            }
        }
    } else {
        error_log('WPGPL Vault Cron Job: Atualização automática de plugins está desativada.');
        wpgpl_vault_add_to_history('Atualização Automática', 'A atualização automática de plugins está desativada.');
    }

    // Verificar se a atualização automática de temas está ativada
    $theme_cron_enabled = wpgpl_vault_get_option('wpgpl_vault_theme_cron_enabled', false);
    $auto_update_themes = wpgpl_vault_get_option('wpgpl_vault_auto_update_themes', []);

    if ($theme_cron_enabled && is_array($auto_update_themes)) {
        foreach ($all_themes as $theme_slug => $theme) {
            $theme_name = $theme->get('Name');
            if (in_array($theme_name, $valid_themes) && in_array($theme_name, $auto_update_themes)) {
                $theme_version = $theme->get('Version');

                $response = wp_remote_get(wpgpl_vault_get_endpoint_url(ENDPOINT_SEARCH) . '?query=' . urlencode($theme_name), array(
                    'headers' => array(
                        'Authorization' => $license_key
                    ),
                    'timeout' => 30
                ));

                if (is_wp_error($response)) {
                    error_log('WPGPL Vault Cron Job: Erro na requisição para o tema ' . $theme_name);
                    wpgpl_vault_add_to_history('Erro na Atualização', 'Erro ao fazer requisição para atualização do tema ' . $theme_name . '.');
                    continue;
                }

                $body = wp_remote_retrieve_body($response);
                $data = json_decode($body, true);

                if (!empty($data) && isset($data[0]['version'])) {
                    if (version_compare($theme_version, $data[0]['version'], '<')) {
                        $download_url = $data[0]['download'];

                        // Usar Theme_Upgrader para atualizar o tema
                        require_once(ABSPATH . 'wp-admin/includes/class-wp-upgrader.php');
                        $upgrader = new Theme_Upgrader();
                        $result = $upgrader->run(array(
                            'package' => $download_url,
                            'destination' => get_theme_root(),
                            'clear_destination' => true, // Sobrescreve o tema existente
                            'clear_working' => true,
                            'hook_extra' => array('type' => 'theme', 'action' => 'update')
                        ));

                        if (is_wp_error($result)) {
                            $error_message = $result->get_error_message();
                            error_log('WPGPL Vault Cron Job: Erro ao atualizar o tema ' . $theme_name . ': ' . $error_message);
                            wpgpl_vault_add_to_history('Erro na Instalação', 'Erro ao atualizar o tema ' . $theme_name . ': ' . $error_message);
                            continue;
                        }

                        error_log('WPGPL Vault Cron Job: Tema ' . $theme_name . ' atualizado com sucesso.');
                        $updated_items[] = array(
                            'type' => 'theme',
                            'name' => $theme_name,
                            'old_version' => $theme_version,
                            'new_version' => $data[0]['version']
                        );
                        
                        // Remover o tema dos itens desatualizados
                        wpgpl_remove_outdated_item($theme_name, false);
                        
                        wpgpl_vault_add_to_history('Tema Atualizado', 'Tema ' . $theme_name . ' atualizado de versão ' . $theme_version . ' para ' . $data[0]['version'] . '.');
                    } else {
                        error_log('WPGPL Vault Cron Job: Tema ' . $theme_name . ' já está atualizado.');
                        wpgpl_vault_add_to_history('Tema Já Atualizado', 'Tema ' . $theme_name . ' já está na versão mais recente (' . $theme_version . ').');
                    }
                } else {
                    error_log('WPGPL Vault Cron Job: Tema ' . $theme_name . ' não foi encontrado na API.');
                    wpgpl_vault_add_to_history('Tema Não Encontrado', 'Tema ' . $theme_name . ' não foi encontrado na API.');
                }

                error_log("Aguardando 10 segundos antes de verificar o próximo tema");
                sleep(10);
            }
        }
    } else {
        error_log('WPGPL Vault Cron Job: Atualização automática de temas está desativada.');
        wpgpl_vault_add_to_history('Atualização Automática', 'A atualização automática de temas está desativada.');
    }

    // Enviar email para o administrador
    if (!empty($updated_items)) {
        $admin_email = get_option('admin_email');
        $subject = $plugin_main_name . ': O seu site foi atualizado com sucesso!';
        $message = "O Cron " . $plugin_main_name . " foi finalizado. Seguem os detalhes das atualizações:\n\n";

        foreach ($updated_items as $item) {
            $message .= ($item['type'] == 'plugin' ? "Plugin " : "Tema ") . $item['name'] . " atualizado de versão " . $item['old_version'] . " para " . $item['new_version'] . ".\n";
        }

        wp_mail($admin_email, $subject, $message);
        wpgpl_vault_update_option('wpgpl_vault_updated_items', $updated_items);
    }

    error_log('WPGPL Vault Cron Job finalizado.');
}
add_action('wpgpl_vault_automatic_updates', 'wpgpl_vault_automatic_updates');
add_action('duplicator_pro_build_completed', 'wpgpl_vault_automatic_updates');
add_action('ai1wm_status_export_done', 'wpgpl_vault_automatic_updates');
add_action('updraft_final_backup_history', 'wpgpl_vault_automatic_updates');

function check_wpgpl_version() {
    
    // Verificar se a licença está ativa
    $license_key = $GLOBALS['wpgpl_license_key'];
    if (empty($license_key)) {
        error_log('WPGPL Check Version: Nenhuma chave de licença encontrada.');
        return;
    }    
    
    $plugin_name = 'WPGPL Vault';
    $url = wpgpl_vault_get_endpoint_url(ENDPOINT_DETAILS) . '?query=' . urlencode($plugin_name);

    $response = wp_remote_get($url, array(
        'headers' => array(
            'Authorization' => $license_key
        ),
        'timeout' => 30
    ));
    if (is_wp_error($response)) {
        error_log('Erro na requisição HTTP: ' . $response->get_error_message());
        return; // Saia da função se houver um erro na requisição
    }

    $body = wp_remote_retrieve_body($response);
    if (empty($body)) {
        error_log('Resposta vazia da requisição HTTP.');
        return;
    }

    $data = json_decode($body, true);
    if (json_last_error() !== JSON_ERROR_NONE) {
        error_log('Erro ao decodificar JSON: ' . json_last_error_msg());
        return;
    }

    // Verificação de dados para estrutura de array
    if (is_array($data) && isset($data[0]['version'])) {
        $remote_version = $data[0]['version'];

        // Atualiza a versão remota nas opções
        wpgpl_vault_update_option('wpgpl_vault_remote_version', $remote_version);

    } else {
        error_log('Dados inesperados na resposta JSON. Dados recebidos: ' . print_r($data, true));
    }
}
add_action('wpgpl_vault_check_wpgpl_version', 'check_wpgpl_version');
?>
