<?php

if (!defined('ABSPATH')) {
    exit;
}

function wpgpl_vault_multisite_automatic_updates($domain, $plugin_or_theme = 'plugin', $index = 0) {
    
    $license_key = $GLOBALS['wpgpl_license_key'];
    if (empty($license_key)) {
        error_log('Chave de licença não fornecida');
        return;
    }
    
    $multisites_data = wpgpl_vault_get_option('wpgpl_multisites_data', []);

    if (!isset($multisites_data[$domain])) {
        error_log("Domínio $domain não encontrado em wpgpl_multisites_data.");
        return;
    }

    $data = $multisites_data[$domain];
    $site_info = $data['site_info'];
    $plugins = $data['plugins'];
    $themes = $data['themes'];
    $updated_items = [];  // Para armazenar plugins/temas atualizados

    // Log de início para o domínio específico
    error_log("WPGPL Vault Cron Job: Processando domínio $domain (Nome: " . $site_info['name'] . ").");

    // Montar lista de plugins e temas
    $plugin_names = array_column($plugins, 'name');
    $theme_names = array_column($themes, 'name');

    // Verificar se os plugins e temas existem no repositório antes de continuar
    $body = [
        'products' => array_merge($plugin_names, $theme_names)
    ];

    // Fazer POST para o endpoint com plugins e temas
    $response = wp_remote_post(wpgpl_vault_get_endpoint_url(ENDPOINT_ITEMS_CHECK), [
        'method' => 'POST',
        'body' => wp_json_encode($body),
        'headers' => [
            'Content-Type' => 'application/json',
            'Authorization' => $license_key
        ],
        'timeout' => 30
    ]);

    // Verificar resposta do endpoint
    if (is_wp_error($response)) {
        error_log("Erro ao fazer a requisição para o endpoint: " . $response->get_error_message());
        return;
    }

    $response_body = wp_remote_retrieve_body($response);
    $products_status = json_decode($response_body, true);

    if (!$products_status || !is_array($products_status)) {
        error_log("Resposta inválida do endpoint.");
        return;
    }

    // Filtrar plugins e temas válidos
    $valid_plugins = [];
    $valid_themes = [];

    foreach ($products_status as $product) {
        if ($product['exists'] === true) {
            if (in_array($product['name'], $plugin_names)) {
                $valid_plugins[] = $product['name'];
            } elseif (in_array($product['name'], $theme_names)) {
                $valid_themes[] = $product['name'];
            }
        }
    }

    // Remove plugins e temas não válidos do array de plugins e temas
    $plugins = array_filter($plugins, function($plugin) use ($valid_plugins) {
        return in_array($plugin['name'], $valid_plugins);
    });

    $themes = array_filter($themes, function($theme) use ($valid_themes) {
        return in_array($theme['name'], $valid_themes);
    });

    // Após a filtragem, certifique-se de que os plugins ou temas não estão vazios
    if ($plugin_or_theme == 'plugin' && $site_info['auto_update_plugins'] && !empty($plugins)) {
        $plugin_keys = array_keys($plugins); // Pegar as chaves do array após a filtragem

        if (isset($plugin_keys[$index])) {
            $plugin = $plugins[$plugin_keys[$index]];
            $plugin_name = $plugin['name'] ?? '';

            if ($plugin['auto_update']) {
                $plugin_version = $plugin['version'];

                // Verificar a versão na API
                error_log("Verificando o plugin $plugin_name no domínio $domain.");
                $response = wp_remote_get(wpgpl_vault_get_endpoint_url(ENDPOINT_SEARCH) . '?query=' . urlencode($plugin_name), array(
                    'headers' => array(
                        'Authorization' => $license_key
                    ),
                    'timeout' => 30
                ));

                if (is_wp_error($response)) {
                    error_log("Erro ao fazer requisição à API para o plugin $plugin_name no domínio $domain. Erro: " . $response->get_error_message());
                } else {
                    $body = wp_remote_retrieve_body($response);
                    $data = json_decode($body, true);

                    if (!empty($data) && isset($data[0]['version']) && version_compare($plugin_version, $data[0]['version'], '<')) {
                        $download_url = $data[0]['download'];
                        error_log("Atualizando o plugin $plugin_name de versão $plugin_version para versão " . $data[0]['version'] . " no domínio $domain.");

                        // Fazer a requisição para a API de instalação
                        $api_response = wp_remote_post("https://$domain/wp-json/wpgpl-child/v1/install", array(
                            'body' => json_encode(array(
                                'url' => $download_url,
                                'type' => 'plugin'
                            )),
                            'headers' => array(
                                'Content-Type' => 'application/json'
                            ),
                            'timeout' => 30
                        ));

                        if (is_wp_error($api_response)) {
                            error_log("Erro ao atualizar o plugin $plugin_name no domínio $domain. Erro: " . $api_response->get_error_message());
                        } else {
                            error_log("Plugin $plugin_name atualizado com sucesso no domínio $domain.");
                            $updated_items[] = "Plugin $plugin_name atualizado de $plugin_version para " . $data[0]['version'];
                        }
                    } else {
                        error_log("Nenhuma atualização necessária para o plugin $plugin_name no domínio $domain.");
                    }
                }
            } else {
                error_log("Auto-update não ativado para o plugin $plugin_name no domínio $domain.");
            }

            // Agendar o próximo plugin com intervalo de 10 segundos
            if (isset($plugin_keys[$index + 1])) {
                error_log("Agendando próxima verificação de plugin para o domínio $domain.");
                as_schedule_single_action(time() + 10, 'wpgpl_vault_multisite_automatic_updates', [$domain, 'plugin', $index + 1], 'wpgpl_vault');
            } else {
                // Iniciar a verificação dos temas após os plugins
                error_log("Iniciando verificação de temas para o domínio $domain.");
                as_schedule_single_action(time() + 10, 'wpgpl_vault_multisite_automatic_updates', [$domain, 'theme', 0], 'wpgpl_vault');
            }
        } else {
            error_log("Nenhum plugin encontrado no índice $index para o domínio $domain.");
        }
    } elseif ($plugin_or_theme == 'theme' || !$site_info['auto_update_plugins']) {
        // Se a verificação de plugins foi desativada ou se estamos verificando temas
        if (!$site_info['auto_update_plugins']) {
            error_log("Atualização automática de plugins desativada para o domínio $domain. Pulando para temas.");
        }

        // Verifica se a atualização automática de temas está ativada e se há temas válidos
        if ($site_info['auto_update_themes'] && !empty($themes)) {
            $theme_keys = array_keys($themes); // Pegar as chaves do array após a filtragem

            if (isset($theme_keys[$index])) {
                $theme = $themes[$theme_keys[$index]];
                $theme_name = $theme['name'] ?? '';

                if ($theme['auto_update']) {
                    $theme_version = $theme['version'];

                    // Verificar a versão na API
                    error_log("Verificando o tema $theme_name no domínio $domain.");
                    $response = wp_remote_get(wpgpl_vault_get_endpoint_url(ENDPOINT_SEARCH) . '?query=' . urlencode($theme_name), array(
                        'headers' => array(
                            'Authorization' => $license_key
                        ),
                        'timeout' => 30
                    ));

                    if (is_wp_error($response)) {
                        error_log("Erro ao fazer requisição à API para o tema $theme_name no domínio $domain. Erro: " . $response->get_error_message());
                    } else {
                        $body = wp_remote_retrieve_body($response);
                        $data = json_decode($body, true);

                        if (!empty($data) && isset($data[0]['version']) && version_compare($theme_version, $data[0]['version'], '<')) {
                            $download_url = $data[0]['download'];
                            error_log("Atualizando o tema $theme_name de versão $theme_version para versão " . $data[0]['version'] . " no domínio $domain.");

                            // Fazer a requisição para a API de instalação
                            $api_response = wp_remote_post("https://$domain/wp-json/wpgpl-child/v1/install", array(
                                'body' => json_encode(array(
                                    'url' => $download_url,
                                    'type' => 'theme'
                                )),
                                'headers' => array(
                                    'Content-Type' => 'application/json'
                                ),
                                'timeout' => 30
                            ));

                            if (is_wp_error($api_response)) {
                                error_log("Erro ao atualizar o tema $theme_name no domínio $domain. Erro: " . $api_response->get_error_message());
                            } else {
                                error_log("Tema $theme_name atualizado com sucesso no domínio $domain.");
                                $updated_items[] = "Tema $theme_name atualizado de $theme_version para " . $data[0]['version'];
                            }
                        } else {
                            error_log("Nenhuma atualização necessária para o tema $theme_name no domínio $domain.");
                        }
                    }
                } else {
                    error_log("Auto-update não ativado para o tema $theme_name no domínio $domain.");
                }

                // Agendar o próximo tema com intervalo de 10 segundos
                if (isset($theme_keys[$index + 1])) {
                    error_log("Agendando próxima verificação de tema para o domínio $domain.");
                    as_schedule_single_action(time() + 10, 'wpgpl_vault_multisite_automatic_updates', [$domain, 'theme', $index + 1], 'wpgpl_vault');
                } else {
                    error_log("Atualização de plugins e temas para o domínio $domain concluída.");

                    // Enviar e-mail ao administrador com os detalhes das atualizações
                    if (!empty($updated_items)) {
                        $admin_email = get_option('admin_email');
                        $subject = "Atualizações no site $domain";
                        $message = "As seguintes atualizações foram realizadas no site $domain:\n\n" . implode("\n", $updated_items);
                        wp_mail($admin_email, $subject, $message);
                        error_log("E-mail enviado ao administrador do domínio $domain.");
                    }
                }
            } else {
                error_log("Nenhum tema encontrado no índice $index para o domínio $domain.");
                error_log("Atualização de plugins e temas para o domínio $domain concluída.");
            }
        } else {
            error_log("Atualização automática de temas desativada para o domínio $domain.");
            error_log("Atualização de plugins e temas para o domínio $domain concluída.");
        }
    }
}
add_action('wpgpl_vault_multisite_automatic_updates', 'wpgpl_vault_multisite_automatic_updates', 10, 3);
?>