<?php

if (!defined('ABSPATH')) {
    exit;
}

function save_wpgpl_child_backup_active() {
    check_ajax_referer('wpgpl_vault_nonce', 'security');

    $domain = sanitize_text_field($_POST['domain']);
    $enabled = (int) $_POST['enabled'];

    // Obter dados do multisite
    $multisites_data = wpgpl_vault_get_option('wpgpl_multisites_data', []);

    // Calcular o número máximo de sites permitidos com funcionalidades ativas
    $max_sites_with_active_features = wpgpl_calculate_max_sites();

    // Contar quantos sites têm pelo menos uma funcionalidade ativa
    $active_sites_count = 0;
    foreach ($multisites_data as $key => $data) {
        if (
            (isset($data['site_info']['auto_update_plugins']) && $data['site_info']['auto_update_plugins'] == 1) ||
            (isset($data['site_info']['auto_update_themes']) && $data['site_info']['auto_update_themes'] == 1) ||
            (isset($data['site_info']['backup_active']) && $data['site_info']['backup_active'] == 1)
        ) {
            // Se o site atual já está com alguma funcionalidade ativa, ele não deve ser contado como um novo site ativo
            if ($key !== $domain || $enabled === 0) {
                $active_sites_count++;
            }
        }
    }

    // Verificar se a quantidade atual de sites ativos atingiu o limite
    if ($enabled === 1 && $active_sites_count >= $max_sites_with_active_features) {
        wp_send_json_error("O número máximo de {$max_sites_with_active_features} sites com funcionalidades ativas foi atingido.");
        return;
    }

    // Verificar se o domínio corresponde a uma chave no array
    $found = false;
    foreach ($multisites_data as $key => $data) {
        if (strpos($key, $domain) !== false) {
            // Atualizar o valor de 'backup_active'
            $multisites_data[$key]['site_info']['backup_active'] = $enabled;
            wpgpl_vault_update_option('wpgpl_multisites_data', $multisites_data);
            $found = true;
            break;
        }
    }

    if ($found) {
        do_action('wpgpl_check_multisite_automatic_update');
        wp_send_json_success();
    } else {
        wp_send_json_error('Domain not found');
    }
}
add_action('wp_ajax_save_wpgpl_child_backup_active', 'save_wpgpl_child_backup_active');

function wpgpl_child_unarchive_item() {
    // Verifique o nonce
    if (!isset($_POST['security']) || !wp_verify_nonce($_POST['security'], 'wpgpl_vault_nonce_field')) {
        wp_send_json_error('Falha na verificação de segurança', 403);
        return;
    }

    // Receba os parâmetros enviados via AJAX
    $domain = sanitize_text_field($_POST['domain']);
    $name = sanitize_text_field($_POST['name']);
    $type = sanitize_text_field($_POST['type']);

    // Recupere as informações atuais do domínio
    $multisites_data = wpgpl_vault_get_option('wpgpl_multisites_data');

    if (isset($multisites_data[$domain])) {
        if ($type === 'plugin') {
            // Percorre os plugins e desmarca como arquivado
            foreach ($multisites_data[$domain]['plugins'] as &$plugin) {
                if ($plugin['name'] === $name) {
                    $plugin['archived'] = 0; // Marca o plugin como desarquivado
                    break;
                }
            }
        } elseif ($type === 'theme') {
            // Percorre os temas e desmarca como arquivado
            foreach ($multisites_data[$domain]['themes'] as &$theme) {
                if ($theme['name'] === $name) {
                    $theme['archived'] = 0; // Marca o tema como desarquivado
                    break;
                }
            }
        }

        // Atualiza os dados no banco
        wpgpl_vault_update_option('wpgpl_multisites_data', $multisites_data);
        wp_send_json_success('Item desarquivado com sucesso.');
    } else {
        wp_send_json_error('Domínio não encontrado.');
    }
}
add_action('wp_ajax_wpgpl_child_unarchive_item', 'wpgpl_child_unarchive_item');

function wpgpl_child_archive_item() {
    // Verifique o nonce
    if (!isset($_POST['security']) || !wp_verify_nonce($_POST['security'], 'wpgpl_vault_nonce_field')) {
        wp_send_json_error('Falha na verificação de segurança', 403);
        return;
    }

    // Receba os parâmetros enviados via AJAX
    $domain = sanitize_text_field($_POST['domain']);
    $name = sanitize_text_field($_POST['name']);
    $type = sanitize_text_field($_POST['type']);

    // Recupere as informações atuais do domínio
    $multisites_data = wpgpl_vault_get_option('wpgpl_multisites_data');

    if (isset($multisites_data[$domain])) {
        if ($type === 'plugin') {
            // Percorre os plugins e marca como arquivado e desativa auto_update
            foreach ($multisites_data[$domain]['plugins'] as &$plugin) {
                if ($plugin['name'] === $name) {
                    $plugin['archived'] = 1;  // Marca o plugin como arquivado
                    $plugin['auto_update'] = 0; // Desativa auto_update
                    break;
                }
            }
        } elseif ($type === 'theme') {
            // Percorre os temas e marca como arquivado e desativa auto_update
            foreach ($multisites_data[$domain]['themes'] as &$theme) {
                if ($theme['name'] === $name) {
                    $theme['archived'] = 1;  // Marca o tema como arquivado
                    $theme['auto_update'] = 0; // Desativa auto_update
                    break;
                }
            }
        }

        // Atualiza os dados no banco
        $update_result = wpgpl_vault_update_option('wpgpl_multisites_data', $multisites_data);
        if (!$update_result) {
            wp_send_json_error('Erro ao atualizar o banco de dados.');
            return;
        }

        wp_send_json_success('Item arquivado com sucesso.');
    } else {
        wp_send_json_error('Domínio não encontrado.');
    }
}

// Função para extrair o site atual da URL
function wpgpl_get_current_site_from_url() {
    if (isset($_GET['site']) && !empty($_GET['site'])) {
        return sanitize_text_field($_GET['site']);
    }
    return false;
}
add_action('wp_ajax_wpgpl_child_archive_item', 'wpgpl_child_archive_item');

function wpgpl_add_site_handler() {
    if (isset($_POST['domain'])) {
        $domain = sanitize_text_field($_POST['domain']);
        
        // Verificar se o domínio fornecido é válido
        if (empty($domain)) {
            wp_send_json_error('Erro: O domínio fornecido está vazio.');
            return;
        }
        
        // Recuperar sites existentes do banco de dados
        $sites = wpgpl_vault_get_option('wpgpl_multisites_data', []);
        if (!is_array($sites)) {
            wp_send_json_error('Erro: Falha ao recuperar os dados existentes de multisites.');
            $sites = [];
        }

        // Verificar se o domínio já está no banco de dados
        if (array_key_exists($domain, $sites)) {
            wp_send_json_error('Erro: O site já está adicionado no banco de dados.');
            return;
        }

        // Obtém o domínio principal do site que está fazendo a requisição
        $current_site_domain = parse_url(home_url(), PHP_URL_HOST);
        
        // Verificar se o domínio principal é válido
        if (empty($current_site_domain)) {
            wp_send_json_error('Erro: Não foi possível determinar o domínio principal do site.');
            return;
        }
        
        // Atualiza a URL para incluir o parâmetro main-domain com o domínio atual do site
        $url = "https://{$domain}/wp-json/wpgpl-child/v1/site-info?main-domain={$current_site_domain}";

        $response = wp_remote_get($url, array(
            'timeout' => 30,
        ));

        if (is_wp_error($response)) {
            $error_message = $response->get_error_message();
            wp_send_json_error("Erro ao conectar ao domínio: {$error_message}");
            return;
        } 

        $status_code = wp_remote_retrieve_response_code($response);
        if ($status_code !== 200) {
            wp_send_json_error("Erro: O domínio não retornou uma resposta 200. Código de status: {$status_code}");
            return;
        }

        $body = wp_remote_retrieve_body($response);
        if (empty($body)) {
            wp_send_json_error('Erro: Corpo da resposta do domínio está vazio.');
            return;
        }

        $site_info = json_decode($body, true);
        if (json_last_error() !== JSON_ERROR_NONE) {
            $json_error = json_last_error_msg();
            // Verifica se a resposta contém HTML (indicativo de um bloqueio, como Cloudflare)
            if (stripos($body, '<html') !== false) {
                // Captura um pequeno trecho da resposta para enviar na mensagem de erro
                $snippet = substr($body, 0, 200);
                wp_send_json_error("Erro: Resposta do domínio contém HTML, possivelmente devido a um bloqueio ou proteção. Trecho da resposta: '{$snippet}'");
            } else {
                wp_send_json_error("Erro: Falha ao decodificar JSON da resposta do domínio. Erro: {$json_error}");
            }
            return;
        }

        // Verificar se os dados são válidos
        if (!isset($site_info['site_info']) || !isset($site_info['plugins']) || !isset($site_info['themes'])) {
            wp_send_json_error('Erro: Estrutura de resposta do site é inválida. Certifique-se de que o domínio está usando o plugin correto.');
            return;
        }

        // Adicionar o novo site ao array
        $sites[$domain] = $site_info;

        // Salvar o array atualizado no banco de dados
        $save_status = wpgpl_vault_update_option('wpgpl_multisites_data', $sites);
        if (!$save_status) {
            wp_send_json_error('Erro: Falha ao salvar as informações do site no banco de dados.');
            return;
        }
        
        do_action('wpgpl_check_multisite_automatic_update');

        wp_send_json_success('Informações do site adicionadas com sucesso.');
    } else {
        wp_send_json_error('Erro: Domínio não fornecido na solicitação.');
    }
}
add_action('wp_ajax_wpgpl_add_site', 'wpgpl_add_site_handler');

function wpgpl_child_ajax_delete_authorized_ip() {
    // Recebe o domínio (URL) passado pelo AJAX
    $current_site_url = isset($_POST['current_site_url']) ? sanitize_text_field($_POST['current_site_url']) : '';

    // Verifica se o domínio foi fornecido
    if (empty($current_site_url)) {
        wp_send_json_error(array('message' => 'URL do site não fornecido.'));
    }

    // Remover o domínio do banco de dados
    $sites = wpgpl_vault_get_option('wpgpl_multisites_data', []);

    // Verifica se o domínio (URL do site) existe no banco de dados
    if (array_key_exists($current_site_url, $sites)) {
        unset($sites[$current_site_url]); // Remove o domínio do array

        // Atualiza o banco de dados com o array modificado
        $update_success = wpgpl_vault_update_option('wpgpl_multisites_data', $sites);
        
        do_action('wpgpl_check_multisite_automatic_update');

        if (!$update_success) {
            wp_send_json_error(array('message' => 'Falha ao remover o domínio do banco de dados.'));
        }
    } else {
        wp_send_json_error(array('message' => 'Domínio não encontrado no banco de dados.'));
    }

    // Faz a chamada para o endpoint REST para remover o IP autorizado
    $response = wp_remote_request( "https://{$current_site_url}/wp-json/wpgpl-child/v1/delete/", array(
        'method' => 'DELETE',
        'headers' => array(
            'Content-Type' => 'application/json',
        ),
        'timeout' => 30
    ));

    // Verifica se houve erro na requisição
    if (is_wp_error($response)) {
        wp_send_json_error(array('message' => 'Erro ao chamar a API REST.'));
    }

    // Verifica o código de resposta da API
    $status_code = wp_remote_retrieve_response_code($response);
    if ($status_code !== 200) {
        wp_send_json_error(array('message' => 'Erro ao deletar o IP autorizado.'));
    }

    // Caso tudo ocorra bem
    wp_send_json_success(array('message' => 'Domínio desconectado com sucesso.'));
}
add_action('wp_ajax_delete_authorized_ip', 'wpgpl_child_ajax_delete_authorized_ip');
add_action('wp_ajax_nopriv_delete_authorized_ip', 'wpgpl_child_ajax_delete_authorized_ip');

function wpgpl_child_download_and_install_callback() {
    $name = isset($_POST['name']) ? sanitize_text_field($_POST['name']) : '';
    $version = isset($_POST['version']) ? sanitize_text_field($_POST['version']) : ''; // Captura a versão se enviada
    $license_key = $GLOBALS['wpgpl_license_key'];
    $type = isset($_POST['type']) ? sanitize_text_field($_POST['type']) : 'plugin'; // Tipo de instalação: plugin ou tema
    $domain = isset($_POST['domain']) ? sanitize_text_field($_POST['domain']) : '';  // Domínio vindo da requisição JS

    if (empty($name)) {
        error_log('wpgpl_child_download_and_install_callback: Nome não fornecido');
        wp_send_json_error('Nome não fornecido');
    }

    if (empty($license_key)) {
        error_log('wpgpl_child_download_and_install_callback: Chave de licença não fornecida');
        wp_send_json_error('Chave de licença não fornecida');
    }

    if (!in_array($type, ['plugin', 'theme'])) {
        error_log('wpgpl_child_download_and_install_callback: Tipo inválido fornecido: ' . $type);
        wp_send_json_error('Tipo inválido fornecido');
    }

    if (empty($domain)) {
        error_log('wpgpl_child_download_and_install_callback: Domínio não fornecido');
        wp_send_json_error('Domínio não fornecido');
    }

    // Faz a requisição para buscar os dados do plugin/tema
    $endpoint_url = wpgpl_vault_get_endpoint_url(ENDPOINT_SEARCH) . '?query=' . urlencode($name);
    error_log('wpgpl_child_download_and_install_callback: URL do endpoint: ' . $endpoint_url);

    $response = wp_remote_get($endpoint_url, array(
        'headers' => array(
            'Authorization' => $license_key
        ),
        'timeout' => 30
    ));

    if (is_wp_error($response)) {
        $error_message = $response->get_error_message();
        error_log('wpgpl_child_download_and_install_callback: Erro na requisição ao buscar dados do plugin/tema. Erro: ' . $error_message);
        wpgpl_vault_add_to_history('Erro na Requisição de Instalação', 'Erro ao fazer requisição para instalar ' . $type . ' "' . $name . '": ' . $error_message);
        wp_send_json_error('Erro na requisição');
    }

    $body = wp_remote_retrieve_body($response);
    $data = json_decode($body, true);

    // Verifica se a resposta contém dados válidos
    if (empty($data) || !isset($data[0])) {
        error_log('wpgpl_child_download_and_install_callback: Nenhum dado de download retornado para o ' . $type . ' "' . $name . '"');
        wp_send_json_error('Nenhum dado de download retornado');
    }

    $download_url = '';

    // Procura pela versão específica, se informada
    if (!empty($version)) {
        foreach ($data[0]['old_versions'] as $old_version) {
            if ($old_version['old_version'] === $version) {
                $download_url = $old_version['old_download'];
                error_log('wpgpl_child_download_and_install_callback: URL de download da versão antiga: ' . $download_url);
                break;
            }
        }

        if (empty($download_url)) {
            error_log('wpgpl_child_download_and_install_callback: Versão antiga não encontrada para: ' . $name . ', Versão: ' . $version);
            wp_send_json_error('Versão antiga não encontrada');
        }
    } else {
        // Se a versão não foi informada, usa a versão atual
        $download_url = $data[0]['download'];
        error_log('wpgpl_child_download_and_install_callback: URL de download da versão atual: ' . $download_url);
    }

    // Agora fazemos a requisição POST para a nova API, passando URL e tipo
    $api_url = "https://$domain/wp-json/wpgpl-child/v1/install";
    error_log('wpgpl_child_download_and_install_callback: Fazendo requisição para API: ' . $api_url);

    $api_response = wp_remote_post($api_url, array(
        'body' => json_encode(array(
            'url' => $download_url,  // URL de download do arquivo
            'type' => $type           // Tipo de instalação (plugin ou tema)
        )),
        'headers' => array(
            'Content-Type' => 'application/json'
        ),
        'timeout' => 30
    ));

    if (is_wp_error($api_response)) {
        $error_message = $api_response->get_error_message();
        error_log('wpgpl_child_download_and_install_callback: Erro na requisição à API. Erro: ' . $error_message);
        wpgpl_vault_add_to_history('Erro na Instalação via API', 'Erro ao instalar o ' . $type . ' "' . $name . '" via API: ' . $error_message);
        wp_send_json_error('Erro na instalação via API: ' . $error_message);
    }

    // Verifica a resposta da API
    $api_body = wp_remote_retrieve_body($api_response);
    error_log('wpgpl_child_download_and_install_callback: Resposta bruta da API: ' . $api_body);

    // Verifica se a resposta é um valor booleano simples (true/false)
    if ($api_body === 'true') {
        error_log('wpgpl_child_download_and_install_callback: ' . $type . ' "' . $name . '" instalado com sucesso');
        wpgpl_vault_add_to_history(ucfirst($type) . ' Instalado', 'O ' . $type . ' "' . $name . '" foi instalado com sucesso');
        wp_send_json_success('Arquivo instalado com sucesso');
    }

    // Tentativa de decodificar a resposta JSON
    $api_data = json_decode($api_body, true);

    if (json_last_error() !== JSON_ERROR_NONE) {
        $json_error = json_last_error_msg();
        error_log('wpgpl_child_download_and_install_callback: Erro ao decodificar JSON da API. Erro: ' . $json_error);
        wp_send_json_error('Erro ao decodificar JSON da resposta da API');
    }

    error_log('wpgpl_child_download_and_install_callback: Resposta da API (decodificada): ' . print_r($api_data, true));

    if (!empty($api_data) && isset($api_data['success']) && $api_data['success']) {
        // Sucesso na instalação
        $action = ucfirst($type) . ' Instalado';
        $content = 'O ' . $type . ' "' . $name . '" foi instalado com sucesso';
        if (!empty($version)) {
            $content .= ' na versão ' . $version;
        }
        wpgpl_vault_add_to_history($action, $content);

        error_log('wpgpl_child_download_and_install_callback: ' . $type . ' "' . $name . '" instalado com sucesso');
        wp_send_json_success('Arquivo instalado com sucesso');
    } else {
        $error_message = isset($api_data['message']) ? $api_data['message'] : 'Erro desconhecido na API';
        error_log('wpgpl_child_download_and_install_callback: Erro ao instalar o arquivo. Mensagem da API: ' . $error_message);
        wpgpl_vault_add_to_history('Erro na Instalação via API', 'Erro ao instalar o ' . $type . ' "' . $name . '": ' . $error_message);
        wp_send_json_error('Erro ao instalar o arquivo: ' . $error_message);
    }
}
add_action('wp_ajax_wpgpl_child_download_and_install', 'wpgpl_child_download_and_install_callback');

function save_wpgpl_child_plugin_cron() {
    check_ajax_referer('wpgpl_vault_nonce', 'security');

    if (!isset($_POST['domain']) || !isset($_POST['plugin_cron_enabled'])) {
        wp_send_json_error('Missing required parameters.');
        return;
    }

    $domain = sanitize_text_field($_POST['domain']);
    $plugin_cron_enabled = intval($_POST['plugin_cron_enabled']);

    // Obter dados do multisite
    $multisites_data = wpgpl_vault_get_option('wpgpl_multisites_data', []);

    if (!is_array($multisites_data) || !isset($multisites_data[$domain])) {
        wp_send_json_error('Domain not found.');
        return;
    }

    // Calcular o número máximo de sites permitidos com funcionalidades ativas
    $max_sites_with_active_features = wpgpl_calculate_max_sites();

    // Contar quantos sites têm pelo menos uma funcionalidade ativa
    $active_sites_count = 0;
    foreach ($multisites_data as $key => $data) {
        if (
            (isset($data['site_info']['auto_update_plugins']) && $data['site_info']['auto_update_plugins'] == 1) ||
            (isset($data['site_info']['auto_update_themes']) && $data['site_info']['auto_update_themes'] == 1) ||
            (isset($data['site_info']['backup_active']) && $data['site_info']['backup_active'] == 1)
        ) {
            // Se o site atual já está com alguma funcionalidade ativa, ele não deve ser contado como um novo site ativo
            if ($key !== $domain || $plugin_cron_enabled === 0) {
                $active_sites_count++;
            }
        }
    }

    // Verificar se a quantidade atual de sites ativos atingiu o limite
    if ($plugin_cron_enabled === 1 && $active_sites_count >= $max_sites_with_active_features) {
        wp_send_json_error("O número máximo de {$max_sites_with_active_features} sites com funcionalidades ativas foi atingido.");
        return;
    }

    // Atualiza o valor de plugin_cron
    $multisites_data[$domain]['site_info']['auto_update_plugins'] = $plugin_cron_enabled;

    // Salva os dados atualizados no banco de dados
    $update_result = wpgpl_vault_update_option('wpgpl_multisites_data', $multisites_data);
    
    do_action('wpgpl_check_multisite_automatic_update');

    if (!$update_result) {
        wp_send_json_error('Failed to update option.');
        return;
    }

    wp_send_json_success();
}
add_action('wp_ajax_save_wpgpl_child_plugin_cron', 'save_wpgpl_child_plugin_cron');

function save_wpgpl_child_theme_cron() {
    check_ajax_referer('wpgpl_vault_nonce', 'security');

    if (!isset($_POST['domain']) || !isset($_POST['theme_cron_enabled'])) {
        wp_send_json_error('Missing required parameters.');
        return;
    }

    $domain = sanitize_text_field($_POST['domain']);
    $theme_cron_enabled = intval($_POST['theme_cron_enabled']);

    // Obter dados do multisite
    $multisites_data = wpgpl_vault_get_option('wpgpl_multisites_data', []);

    if (!is_array($multisites_data) || !isset($multisites_data[$domain])) {
        wp_send_json_error('Domain not found.');
        return;
    }

    // Calcular o número máximo de sites permitidos com funcionalidades ativas
    $max_sites_with_active_features = wpgpl_calculate_max_sites();

    // Contar quantos sites têm pelo menos uma funcionalidade ativa
    $active_sites_count = 0;
    foreach ($multisites_data as $key => $data) {
        if (
            (isset($data['site_info']['auto_update_plugins']) && $data['site_info']['auto_update_plugins'] == 1) ||
            (isset($data['site_info']['auto_update_themes']) && $data['site_info']['auto_update_themes'] == 1) ||
            (isset($data['site_info']['backup_active']) && $data['site_info']['backup_active'] == 1)
        ) {
            // Se o site atual já está com alguma funcionalidade ativa, ele não deve ser contado como um novo site ativo
            if ($key !== $domain || $theme_cron_enabled === 0) {
                $active_sites_count++;
            }
        }
    }

    // Verificar se a quantidade atual de sites ativos atingiu o limite
    if ($theme_cron_enabled === 1 && $active_sites_count >= $max_sites_with_active_features) {
        wp_send_json_error("O número máximo de {$max_sites_with_active_features} sites com funcionalidades ativas foi atingido.");
        return;
    }

    // Atualiza o valor de theme_cron
    $multisites_data[$domain]['site_info']['auto_update_themes'] = $theme_cron_enabled;

    // Salva os dados atualizados no banco de dados
    $update_result = wpgpl_vault_update_option('wpgpl_multisites_data', $multisites_data);
    
    do_action('wpgpl_check_multisite_automatic_update');

    if (!$update_result) {
        wp_send_json_error('Failed to update option.');
        return;
    }

    wp_send_json_success();
}
add_action('wp_ajax_save_wpgpl_child_theme_cron', 'save_wpgpl_child_theme_cron');

function save_wpgpl_child_auto_update_plugin() {
    check_ajax_referer('wpgpl_vault_nonce', 'security');

    if (!isset($_POST['domain']) || !isset($_POST['plugin']) || !isset($_POST['enabled'])) {
        wp_send_json_error('Missing required parameters.');
        return;
    }

    $domain = sanitize_text_field($_POST['domain']);
    $plugin_name = sanitize_text_field($_POST['plugin']);
    $enabled = intval($_POST['enabled']);

    // Obtém os dados serializados do banco de dados
    $multisites_data = wpgpl_vault_get_option('wpgpl_multisites_data', []);

    if (!is_array($multisites_data) || !isset($multisites_data[$domain])) {
        wp_send_json_error('Domain not found.');
        return;
    }

    // Atualiza o `auto_update` do plugin individual
    foreach ($multisites_data[$domain]['plugins'] as &$plugin) {
        if ($plugin['name'] === $plugin_name) {
            $plugin['auto_update'] = $enabled ? 1 : 0;
            break;
        }
    }

    // Salva os dados atualizados no banco de dados
    $update_result = wpgpl_vault_update_option('wpgpl_multisites_data', $multisites_data);

    if (!$update_result) {
        wp_send_json_error('Failed to update option.');
        return;
    }

    wp_send_json_success();
}
add_action('wp_ajax_save_wpgpl_child_auto_update_plugin', 'save_wpgpl_child_auto_update_plugin');

function save_wpgpl_child_auto_update_theme() {
    check_ajax_referer('wpgpl_vault_nonce', 'security');

    if (!isset($_POST['domain']) || !isset($_POST['theme']) || !isset($_POST['enabled'])) {
        wp_send_json_error('Missing required parameters.');
        return;
    }

    $domain = sanitize_text_field($_POST['domain']);
    $theme_name = sanitize_text_field($_POST['theme']);
    $enabled = intval($_POST['enabled']);

    // Obtém os dados serializados do banco de dados
    $multisites_data = wpgpl_vault_get_option('wpgpl_multisites_data', []);

    if (!is_array($multisites_data) || !isset($multisites_data[$domain])) {
        wp_send_json_error('Domain not found.');
        return;
    }

    // Atualiza o `auto_update` do tema individual
    foreach ($multisites_data[$domain]['themes'] as &$theme) {
        if ($theme['name'] === $theme_name) {
            $theme['auto_update'] = $enabled ? 1 : 0;
            break;
        }
    }

    // Salva os dados atualizados no banco de dados
    $update_result = wpgpl_vault_update_option('wpgpl_multisites_data', $multisites_data);

    if (!$update_result) {
        wp_send_json_error('Failed to update option.');
        return;
    }

    wp_send_json_success();
}
add_action('wp_ajax_save_wpgpl_child_auto_update_theme', 'save_wpgpl_child_auto_update_theme');