<?php

if (!defined('ABSPATH')) {
    exit;
}

function wpgpl_vault_update_site_info() {
    register_rest_route('wpgpl-vault/v1', '/update-site/', array(
        'methods' => 'PUT',
        'callback' => 'wpgpl_update_site_info',
        'permission_callback' => '__return_true', // Pode ser ajustado para verificar permissões específicas
        'args' => array(
            'domain' => array(
                'required' => true,
                'validate_callback' => function($param, $request, $key) {
                    return is_string($param); // Verifica se o domínio é uma string válida
                }
            ),
        ),
    ));
}
add_action('rest_api_init', 'wpgpl_vault_update_site_info');

function wpgpl_update_site_info(WP_REST_Request $request) {
    // Pega o domínio direto da URL
    $domain = sanitize_text_field($request->get_param('domain'));

    // Pega os dados do corpo da requisição
    $params = $request->get_json_params();

    // Verifica se os parâmetros necessários estão presentes
    if (!isset($params['site_info']) || !isset($params['plugins']) || !isset($params['themes'])) {
        return new WP_REST_Response('Dados insuficientes fornecidos.', 400);
    }

    $site_info = $params['site_info'];
    $plugins = $params['plugins'];
    $themes = $params['themes'];

    // Recuperar os sites salvos no banco de dados
    $sites = wpgpl_vault_get_option('wpgpl_multisites_data', []);

    // Verifica se o domínio existe no banco de dados
    if (array_key_exists($domain, $sites)) {
        // Mantém os valores de 'auto_update_plugins' e 'auto_update_themes' se existirem
        $site_info['auto_update_plugins'] = isset($sites[$domain]['site_info']['auto_update_plugins']) 
            ? $sites[$domain]['site_info']['auto_update_plugins'] 
            : null;
        $site_info['auto_update_themes'] = isset($sites[$domain]['site_info']['auto_update_themes']) 
            ? $sites[$domain]['site_info']['auto_update_themes'] 
            : null;

        // Atualiza as informações do site mantendo 'auto_update' e 'archived' inalterados
        foreach ($plugins as $index => $plugin) {
            if (isset($sites[$domain]['plugins'][$index])) {
                // Mantém os valores de 'auto_update' e 'archived' se existirem
                $plugin['auto_update'] = isset($sites[$domain]['plugins'][$index]['auto_update']) 
                    ? $sites[$domain]['plugins'][$index]['auto_update'] 
                    : null;
                $plugin['archived'] = isset($sites[$domain]['plugins'][$index]['archived']) 
                    ? $sites[$domain]['plugins'][$index]['archived'] 
                    : null;
            }
            $plugins[$index] = $plugin;
        }

        foreach ($themes as $index => $theme) {
            if (isset($sites[$domain]['themes'][$index])) {
                // Mantém os valores de 'auto_update' e 'archived' se existirem
                $theme['auto_update'] = isset($sites[$domain]['themes'][$index]['auto_update']) 
                    ? $sites[$domain]['themes'][$index]['auto_update'] 
                    : null;
                $theme['archived'] = isset($sites[$domain]['themes'][$index]['archived']) 
                    ? $sites[$domain]['themes'][$index]['archived'] 
                    : null;
            }
            $themes[$index] = $theme;
        }

        // Atualiza o banco de dados com as novas informações sem alterar 'auto_update' e 'archived'
        $sites[$domain] = [
            'site_info' => $site_info,
            'plugins' => $plugins,
            'themes' => $themes
        ];

        // Salva as alterações no banco de dados
        $updated = wpgpl_vault_update_option('wpgpl_multisites_data', $sites);

        if ($updated) {
            return new WP_REST_Response('Informações do site atualizadas com sucesso.', 200);
        } else {
            return new WP_REST_Response('Falha ao atualizar as informações do site.', 500);
        }
    } else {
        return new WP_REST_Response('Domínio não encontrado no banco de dados.', 404);
    }
}

function wpgpl_vault_delete_domain() {
    register_rest_route('wpgpl-vault/v1', '/delete-domain/', array(
        'methods' => 'DELETE',
        'callback' => 'wpgpl_delete_domain_from_db',
        'permission_callback' => '__return_true',
        'args' => array(
            'domain' => array(
                'required' => true,
                'validate_callback' => function($param, $request, $key) {
                    return is_string($param);
                }
            )
        )
    ));
}
add_action('rest_api_init', 'wpgpl_vault_delete_domain');

function wpgpl_delete_domain_from_db(WP_REST_Request $request) {
    // Domínio passado via request
    $domain_to_delete = $request->get_param('domain');

    // Obtém os dados salvos na opção wpgpl_multisites_data
    $multisites_data = wpgpl_vault_get_option('wpgpl_multisites_data');

    if (empty($multisites_data)) {
        return new WP_Error('no_data', 'Nenhum dado encontrado.', array('status' => 404));
    }

    // Verifica se o domínio existe nos dados
    if (!isset($multisites_data[$domain_to_delete])) {
        return new WP_Error('domain_not_found', 'Domínio não encontrado.', array('status' => 404));
    }

    // Remove o domínio
    unset($multisites_data[$domain_to_delete]);

    // Atualiza a opção com o domínio removido
    wpgpl_vault_update_option('wpgpl_multisites_data', $multisites_data);

    return rest_ensure_response(array(
        'message' => 'Domínio removido com sucesso.'
    ));
}

function wpgpl_vault_schedule_update_domain() {
    register_rest_route('wpgpl-child/v1', '/schedule-update', array(
        'methods' => 'POST',
        'callback' => 'wpgpl_child_schedule_update',
        'permission_callback' => '__return_true' // Ajuste para validar a permissão adequadamente
    ));
}
add_action('rest_api_init', 'wpgpl_vault_schedule_update_domain');

function wpgpl_child_schedule_update($request) {
    // Obtém o domínio do parâmetro de consulta 'site'
    $domain = $request->get_param('site');

    // Verificar se o domínio foi fornecido
    if (empty($domain)) {
        return new WP_Error('missing_domain', "O parâmetro 'site' é obrigatório na URL.", array('status' => 400));
    }

    // Obter os dados dos multisites do banco de dados
    $multisites_data = wpgpl_vault_get_option('wpgpl_multisites_data', []);

    // Verificar se o domínio está presente no banco de dados
    if (!isset($multisites_data[$domain])) {
        return new WP_Error('domain_not_found', "O domínio $domain não foi encontrado no banco de dados.", array('status' => 404));
    }

    // Verificar o status do backup_active com log adicional para verificar o valor
    $site_info = $multisites_data[$domain]['site_info'];
    error_log("Verificando backup_active para o domínio $domain: " . print_r($site_info, true));
    
    $backup_active = isset($site_info['backup_active']) ? $site_info['backup_active'] : false;

    // Adicionar um log para confirmar o valor de backup_active
    error_log("Valor de backup_active para o domínio $domain: " . var_export($backup_active, true));

    // Se backup_active for true, agendar o Action Scheduler
    if ($backup_active) {
        // Verifica se já existe um agendamento ou execução para o domínio, independentemente dos outros parâmetros
        $scheduled_actions = as_get_scheduled_actions(array(
            'hook' => 'wpgpl_vault_multisite_automatic_updates',
            'status' => array('pending', 'in-progress'),
            'per_page' => -1 // Obter todas as ações agendadas correspondentes
        ));

        $action_exists = false;

        // Verifica se há ações com o domínio em qualquer posição nos argumentos
        foreach ($scheduled_actions as $action) {
            $args = $action->get_args(); // Usar o método get_args() para acessar os argumentos

            if (in_array($domain, $args, true)) {
                $action_exists = true;
                break;
            }
        }

        if (!$action_exists) {
            as_schedule_single_action(time(), 'wpgpl_vault_multisite_automatic_updates', [$domain, 'plugin', 0], 'wpgpl_vault');
            error_log("Ação agendada imediatamente para o domínio $domain.");
            return new WP_REST_Response(array('message' => "Ação agendada imediatamente para o domínio $domain."), 200);
        } else {
            return new WP_REST_Response(array('message' => "Ação já está agendada ou em progresso para o domínio $domain."), 200);
        }
    } else {
        error_log("Backup não está ativo para o domínio $domain.");
        return new WP_REST_Response(array('message' => "Backup não está ativo para o domínio $domain."), 200);
    }
}